@@ -12,10 +12,10 @@ require Exporter;
 
 our @ISA        = qw(Exporter);
 our @EXPORT_OK  = qw(
-  all any first min max minstr maxstr none notall product reduce sum sum0 shuffle uniq uniqnum
+  all any first min max minstr maxstr none notall product reduce sum sum0 shuffle uniq uniqnum uniqstr
   pairs unpairs pairkeys pairvalues pairmap pairgrep pairfirst
 );
-our $VERSION    = "1.43_005";
+our $VERSION    = "1.44_001";
 our $XS_VERSION = $VERSION;
 $VERSION    = eval $VERSION;
 
@@ -52,7 +52,7 @@ List::Util - A selection of general-utility list subroutines
 
       pairs pairkeys pairvalues pairfirst pairgrep pairmap
 
-      shuffle
+      shuffle uniqnum uniqstr
     );
 
 =head1 DESCRIPTION
@@ -466,27 +466,64 @@ Returns the values of the input in a random order
 
     my @subset = uniq @values
 
+I<Since version 1.45.>
+
 Filters a list of values to remove subsequent duplicates, as judged by a
-string equality test. Preserves the order of unique elements, and retains the
-first value of any duplicate set.
+DWIM-ish string equality or C<undef> test. Preserves the order of unique
+elements, and retains the first value of any duplicate set.
 
     my $count = uniq @values
 
 In scalar context, returns the number of elements that would have been
 returned as a list.
 
+The C<undef> value is treated by this function as distinct from the empty
+string, and no warning will be produced. It is left as-is in the returned
+list. Subsequent C<undef> values are still considered identical to the first,
+and will be removed.
+
 =head2 uniqnum
 
     my @subset = uniqnum @values
 
-Filters a list of values similarly to L</uniq>, but judges duplicates
-numerically instead.
+I<Since version 1.44.>
+
+Filters a list of values to remove subsequent duplicates, as judged by a
+numerical equality test. Preserves the order of unique elements, and retains
+the first value of any duplicate set.
 
     my $count = uniqnum @values
 
 In scalar context, returns the number of elements that would have been
 returned as a list.
 
+Note that C<undef> is treated much as other numerical operations treat it; it
+compares equal to zero but additionally produces a warning if such warnings
+are enabled (C<use warnings 'uninitialized';>). In addition, an C<undef> in
+the returned list is coerced into a numerical zero, so that the entire list of
+values returned by C<uniqnum> are well-behaved as numbers.
+
+=head2 uniqstr
+
+    my @subset = uniqstr @values
+
+I<Since version 1.45.>
+
+Filters a list of values to remove subsequent duplicates, as judged by a
+string equality test. Preserves the order of unique elements, and retains the
+first value of any duplicate set.
+
+    my $count = uniqstr @values
+
+In scalar context, returns the number of elements that would have been
+returned as a list.
+
+Note that C<undef> is treated much as other string operations treat it; it
+compares equal to the empty string but additionally produces a warning if such
+warnings are enabled (C<use warnings 'uninitialized';>). In addition, an
+C<undef> in the returned list is coerced into an empty string, so that the
+entire list of values returned by C<uniqstr> are well-behaved as strings.
+
 =cut
 
 =head1 KNOWN BUGS
@@ -546,7 +583,7 @@ the native platform types. For example,
  say for uniqnum( $x, $y );
 
 Will print just the value of C<$x>, believing that C<$y> is a numerically-
-equivalent value. This bug does not affect C<uniq()>, which will correctly
+equivalent value. This bug does not affect C<uniqstr()>, which will correctly
 observe that the two values stringify to different strings.
 
 =head2 uniqnum() invokes GET magic multiple times before perl 5.14
@@ -555,7 +592,7 @@ Perl versions before 5.14 lack the C<SvNV_nomg()> and related macros. On these
 older versions, C<uniqnum()> will invoke GET magic twice on each argument
 passed in. This ought not cause any major problems other than a slight
 performance penalty, because well-designed GET magic should be idempotent.
-This does not affect C<uniq()>, nor builds for perl 5.14 or later.
+This does not affect C<uniqstr()>, nor builds for perl 5.14 or later.
 
 =head1 SUGGESTED ADDITIONS
 
